@@ -148,7 +148,7 @@ class HttpRunner(object):
             if not has_attr:
                 for attr in not_need_configured_attr:  # 判断是否有数据源
                     for setup in step.setup:
-                        if attr in setup:
+                        if "&&db:" in setup:
                             has_attr = True
                             break
 
@@ -163,7 +163,7 @@ class HttpRunner(object):
             if not has_attr:
                 for attr in not_need_configured_attr:  # 判断是否有数据源
                     for teardown in step.teardown:
-                        if attr in teardown:
+                        if "&&db:" in teardown:
                             has_attr = True
                             break
 
@@ -183,6 +183,11 @@ class HttpRunner(object):
         prepare_upload_step(step, self.__project_meta.functions)
         request_dict = step.request.dict()
         request_dict.pop("upload", None)
+
+        # setup hooks
+        if step.setup_hooks:
+            self.__call_hooks(step.setup_hooks, step.variables, "setup request")
+
         parsed_request_dict = parse_data(
             request_dict, step.variables, self.__project_meta.functions
         )
@@ -192,10 +197,6 @@ class HttpRunner(object):
         )
         step.variables["request"] = parsed_request_dict
 
-        # setup hooks
-        if step.setup_hooks:
-            self.__call_hooks(step.setup_hooks, step.variables, "setup request")
-
         variables_mapping = step.variables
         # variables_mapping.update(extract_mapping)
         # execute setup
